@@ -51,17 +51,23 @@ so you will need to run 'rdr set -s mallet'.''', err=True )
 
 @click.command( options_metavar='<options>' )
 @click.option('-t', '--topics', default=7, help="number of topics to generate")
-@click.option('-w', '--words', default=30, help="number of words used to describe topic")
+@click.option('-w', '--words', default=7, help="number of words used to describe topic")
 @click.option('-i', '--iterations', default=2400, help="number of iterations")
 @click.argument( 'carrel', metavar='<carrel>' )
 def tm( carrel, topics, words, iterations ) :
 
 	"""Apply topic modeling against <carrel>
 	
-	Topic modeling is the process of enumerating latent themes from a corpus, and it is yet another way to describe a corpus's aboutness. It is suggested you start out small when it comes to the values for --topics and --words. Repeat the modeling process an gradually increase the values."
+	Topic modeling is the process of enumerating latent themes from a corpus, and it is yet another way to describe a corpus's aboutness. It is suggested you start out small when it comes to the values for -t and -w. Repeat the modeling process and gradually increase the values. Increase the value of -i as the size of your carrel increases. 
 	
-	Example: rdr tm homer -t 3 -d 3
-	"""
+	Remember, there is no such thing as the correct value of -t. After all, exactly how many things is the sum of Shakespeare's works about?
+	
+	Examples:
+	
+	\b
+	  rdr tm homer
+	  rdr tm -t 7 -w 12 homer
+	  rdr tm -t 7 -w 24 -i 4800 homer"""
 
 	# configure
 	HTML       = 'topic-model.htm'
